[nasm:master] Change dfmt->debug_macros to dfmt->debug_mmacros

nasm-bot for H. Peter Anvin (Intel) hpa at zytor.com
Tue Aug 25 16:18:05 PDT 2020


Commit-ID:  64c7c763c26c66baa169235f5bfa9ef402e5293c
Gitweb:     http://repo.or.cz/w/nasm.git?a=commitdiff;h=64c7c763c26c66baa169235f5bfa9ef402e5293c
Author:     H. Peter Anvin (Intel) <hpa at zytor.com>
AuthorDate: Tue, 14 Jul 2020 12:05:03 -0700
Committer:  H. Peter Anvin (Intel) <hpa at zytor.com>
CommitDate: Tue, 14 Jul 2020 12:05:03 -0700

Change dfmt->debug_macros to dfmt->debug_mmacros

... in preparation for adding dfmt->debug_smacros.

Signed-off-by: H. Peter Anvin (Intel) <hpa at zytor.com>


---
 asm/preproc.c     |  4 ++--
 include/nasm.h    |  4 ++--
 output/codeview.c |  2 +-
 output/nulldbg.c  |  2 +-
 output/outdbg.c   |  4 ++--
 output/outelf.c   | 12 ++++++------
 output/outieee.c  |  2 +-
 output/outmacho.c |  4 ++--
 output/outobj.c   |  2 +-
 9 files changed, 18 insertions(+), 18 deletions(-)

diff --git a/asm/preproc.c b/asm/preproc.c
index c1c72193..b5a500dc 100644
--- a/asm/preproc.c
+++ b/asm/preproc.c
@@ -6333,7 +6333,7 @@ static void free_debug_macro_info(void)
 static void debug_macro_output(void)
 {
     list_reverse(dmi.inv.l);
-    dfmt->debug_macros(&dmi);
+    dfmt->debug_mmacros(&dmi);
     free_debug_macro_info();
 }
 
@@ -6772,7 +6772,7 @@ void pp_reset(const char *file, enum preproc_mode mode,
     ppdbg = 0;
     if (!(ppopt & PP_TRIVIAL)) {
         if (pass_final()) {
-            if (dfmt->debug_macros)
+            if (dfmt->debug_mmacros)
                 ppdbg |= PDBG_MACROS;
         }
     }
diff --git a/output/codeview.c b/output/codeview.c
index f424bec6..9b12c136 100644
--- a/output/codeview.c
+++ b/output/codeview.c
@@ -64,7 +64,7 @@ const struct dfmt df_cv8 = {
     cv8_init,                   /* .init */
     cv8_linenum,                /* .linenum */
     cv8_deflabel,               /* .debug_deflabel */
-    NULL,                       /* .debug_macros */
+    NULL,                       /* .debug_mmacros */
     null_debug_directive,       /* .debug_directive */
     cv8_typevalue,              /* .debug_typevalue */
     cv8_output,                 /* .debug_output */
diff --git a/output/nulldbg.c b/output/nulldbg.c
index 7b422357..a8a9dcd9 100644
--- a/output/nulldbg.c
+++ b/output/nulldbg.c
@@ -83,7 +83,7 @@ const struct dfmt null_debug_form = {
     null_debug_init,
     null_debug_linenum,
     null_debug_deflabel,
-    NULL,                       /* .debug_macros */
+    NULL,                       /* .debug_mmacros */
     null_debug_directive,
     null_debug_typevalue,
     null_debug_output,
diff --git a/output/outdbg.c b/output/outdbg.c
index db933294..7c4065b1 100644
--- a/output/outdbg.c
+++ b/output/outdbg.c
@@ -485,7 +485,7 @@ write_macro_inv_list(const struct debug_macro_inv *inv, int level)
     }
 }
 
-static void dbgdbg_debug_macros(const struct debug_macro_info *dmi)
+static void dbgdbg_debug_mmacros(const struct debug_macro_info *dmi)
 {
     const struct debug_macro_def *def;
 
@@ -516,7 +516,7 @@ static const struct dfmt debug_debug_form = {
     dbgdbg_init,
     dbgdbg_linnum,
     dbgdbg_deflabel,
-    dbgdbg_debug_macros,
+    dbgdbg_debug_mmacros,
     dbgdbg_define,
     dbgdbg_typevalue,
     dbgdbg_output,
diff --git a/output/outelf.c b/output/outelf.c
index c80e9b99..c87a6f18 100644
--- a/output/outelf.c
+++ b/output/outelf.c
@@ -2435,7 +2435,7 @@ static const struct dfmt elf32_df_dwarf = {
     dwarf32_init,
     dwarf_linenum,
     null_debug_deflabel,
-    NULL,                       /* .debug_macros */
+    NULL,                       /* .debug_mmacros */
     null_debug_directive,
     debug_typevalue,
     dwarf_output,
@@ -2449,7 +2449,7 @@ static const struct dfmt elf32_df_stabs = {
     null_debug_init,
     stabs_linenum,
     null_debug_deflabel,
-    NULL,                       /* .debug_macros */
+    NULL,                       /* .debug_mmacros */
     null_debug_directive,
     debug_typevalue,
     stabs_output,
@@ -2489,7 +2489,7 @@ static const struct dfmt elf64_df_dwarf = {
     dwarf64_init,
     dwarf_linenum,
     null_debug_deflabel,
-    NULL,                       /* .debug_macros */
+    NULL,                       /* .debug_mmacros */
     null_debug_directive,
     debug_typevalue,
     dwarf_output,
@@ -2503,7 +2503,7 @@ static const struct dfmt elf64_df_stabs = {
     null_debug_init,
     stabs_linenum,
     null_debug_deflabel,
-    NULL,                       /* .debug_macros */
+    NULL,                       /* .debug_mmacros */
     null_debug_directive,
     debug_typevalue,
     stabs_output,
@@ -2543,7 +2543,7 @@ static const struct dfmt elfx32_df_dwarf = {
     dwarfx32_init,
     dwarf_linenum,
     null_debug_deflabel,
-    NULL,                       /* .debug_macros */
+    NULL,                       /* .debug_mmacros */
     null_debug_directive,
     debug_typevalue,
     dwarf_output,
@@ -2557,7 +2557,7 @@ static const struct dfmt elfx32_df_stabs = {
     null_debug_init,
     stabs_linenum,
     null_debug_deflabel,
-    NULL,                       /* .debug_macros */
+    NULL,                       /* .debug_mmacros */
     null_debug_directive,
     debug_typevalue,
     stabs_output,
diff --git a/output/outieee.c b/output/outieee.c
index f474b8e5..3c89a00f 100644
--- a/output/outieee.c
+++ b/output/outieee.c
@@ -1464,7 +1464,7 @@ static const struct dfmt ladsoft_debug_form = {
     dbgls_init,
     dbgls_linnum,
     dbgls_deflabel,
-    NULL,                       /* .debug_macros */
+    NULL,                       /* .debug_mmacros */
     null_debug_directive,
     dbgls_typevalue,
     dbgls_output,
diff --git a/output/outmacho.c b/output/outmacho.c
index e3dbb850..b7fe1c36 100644
--- a/output/outmacho.c
+++ b/output/outmacho.c
@@ -2289,7 +2289,7 @@ static const struct dfmt macho32_df_dwarf = {
     macho_dbg_init,
     macho_dbg_linenum,
     null_debug_deflabel,
-    NULL,                       /* .debug_macros */
+    NULL,                       /* .debug_mmacros */
     null_debug_directive,
     null_debug_typevalue,
     macho_dbg_output,
@@ -2357,7 +2357,7 @@ static const struct dfmt macho64_df_dwarf = {
     macho_dbg_init,
     macho_dbg_linenum,
     null_debug_deflabel,
-    NULL,                       /* .debug_macros */
+    NULL,                       /* .debug_mmacros */
     null_debug_directive,
     null_debug_typevalue,
     macho_dbg_output,
diff --git a/output/outobj.c b/output/outobj.c
index 09693207..ce557744 100644
--- a/output/outobj.c
+++ b/output/outobj.c
@@ -2650,7 +2650,7 @@ static const struct dfmt borland_debug_form = {
     dbgbi_init,
     dbgbi_linnum,
     dbgbi_deflabel,
-    NULL,                       /* .debug_macros */
+    NULL,                       /* .debug_mmacros */
     null_debug_directive,
     dbgbi_typevalue,
     dbgbi_output,


More information about the Nasm-commits mailing list
diff --git a/include/nasm.h b/include/nasm.h
index 115084ae..92bc60c2 100644
--- a/include/nasm.h
+++ b/include/nasm.h
@@ -1104,11 +1104,11 @@ struct dfmt {
                            int is_global, char *special);
 
     /*
      * debug_macros - called once at the end with a definition for each
      * non-.nolist macro that has been invoked at least once in the program,
      * and the corresponding address ranges. See dbginfo.h.
      */
-    void (*debug_macros)(const struct debug_macro_info *);
+    void (*debug_mmacros)(const struct debug_macro_info *);
 
     /*
      * debug_directive - called whenever a DEBUG directive other than 'LINE'
@@ -1104,11 +1104,11 @@ struct dfmt {
 
     /*
-     * debug_macros - called once at the end with a definition for each
+     * debug_mmacros - called once at the end with a definition for each
      * non-.nolist macro that has been invoked at least once in the program,
      * and the corresponding address ranges. See dbginfo.h.